/**
 * @file TLC5947.h
 *
 * @brief Library for TLC5947 LED Driver
 *
 * For serial communication via USART in Master SPI Mode.
 *
 * Required connections are:
 *  - TXD  -> SIN
 *  - XCK  -> SCLK
 *  - GPIO -> XLAT
 *  - GPIO -> BLANK
 *
 * @author Robert Steigemann
 *
 * @test Tested with ATmega48 @ 16 MHz and USART0 with only one TLC5947.
 */ 

#ifndef TLC5947_H_
#define TLC5947_H_

#include <avr/io.h>

// Setup your hardware here:
#define TLC5947_CHIPS	1		// how many chips are daisy chained?
#define TLC5947_USART	0		// which USART are used? 

#define TLC5947_PORT	PORTD	// The used PORT
#define TLC5947_DDR		DDRD	// The corresponding DDR Register

#define TLC5947_DATA	PD1		// Serial Data Out (TXD)
#define TLC5947_SCLK	PD4		// Serial Clock Out (XCK)
#define TLC5947_XLAT	PD0		// Latch Signal (GPIO)
#define TLC5947_BLANK	PD2		// Blank Signal (GPIO)


/**
 * @brief Initialize the USART and TLC5947
 *
 * Call it one time after startup. Turn all LEDs off.
 */
void tlc5947_init(void);


/**
 * @brief Change the brightness of a LED
 *
 * You have to call tlc5947_update() to transfer this change to the TLC5947!
 *
 * @param chip The chip in the daisy chain (0 - TLC5947_CHIPS-1)
 * @param channel The channel of the chip (0 - 23)
 * @param brightness The level of the LED (0-4095)
 */
void tlc5947_set(uint8_t chip, uint8_t channel, uint16_t brightness);


/**
 * @brief Transfer the the set brightness values to the TLC5947 driver(s)
 *
 * Call it after changes with tlc5947_set() was made.
 */
void tlc5947_update(void);


#endif /* TLC5947_H_ */